from setuptools import setup, find_packages

classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='cleaner_id',
  version='0.0.3',
  description='Text Preprocessing untuk bahasa Indonesia',
  long_description='',
  url='',  
  author='Tarangga Arief',
  author_email='tarangga.arief@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='text preprocessing', 
  packages=find_packages(),
  install_requires=[''] 
)